@@ -2,7 +2,7 @@
 
 namespace openmittsu {
 	namespace options {
-		uint qHash(openmittsu::options::Options const& key, uint seed) {
+		utility::QtHashSizeType qHash(openmittsu::options::Options const& key, utility::QtHashSizeType seed) {
 			return ::qHash(static_cast<std::size_t>(key), seed);
 		}
 	}
