@@ -4,6 +4,11 @@
 #include <QAudioOutput>
 #include <QFile>
 #include <QObject>
+#include <QtVersionChecks>
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QAudioSink>
+#endif
 
 #include <memory>
 
@@ -23,7 +28,11 @@ namespace openmittsu {
 		private:
 			// Audio playing
 			QFile receivedMessageAudioFile;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+			std::unique_ptr<QAudioSink> audioSink;
+#else
 			std::unique_ptr<QAudioOutput> audioOutput;
+#endif
 		};
 
 	}
